==> hs-blaze-builder-0.3.1.1.tgz: lib/ghc/blaze-builder-0.3.1.1/register.sh <==
#!/bin/sh
echo 'name: blaze-builder
version: 0.3.1.1
id: blaze-builder-0.3.1.1-ac49b512143342e2370aead8ef93c70b

license: BSD3
copyright: 2010 Simon Meier
           2010 Jasper Van der Jeugt
maintainer: Simon Meier <iridcode@gmail.com>
stability: Experimental
homepage: http://github.com/meiersi/blaze-builder
package-url:
synopsis: Efficient buffered output.
description: This library provides an abstraction of buffered output of
             byte streams and several convenience functions to exploit
             it. For example, it allows to efficiently serialize
             Haskell values to lazy bytestrings with a large average
             chunk size. The large average chunk size allows to make
             good use of cache prefetching in later processing steps
             (e.g. compression) and reduces the sytem call overhead
             when writing the resulting lazy bytestring to a file or
             sending it over the network.
category: Data
author: Jasper Van der Jeugt, Simon Meier
pkgpath: devel/hs-blaze-builder
exposed: True
exposed-modules: Blaze.ByteString.Builder
                 Blaze.ByteString.Builder.Int Blaze.ByteString.Builder.Word
                 Blaze.ByteString.Builder.ByteString
                 Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
                 Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.HTTP
                 Blaze.ByteString.Builder.Internal
                 Blaze.ByteString.Builder.Internal.Write
                 Blaze.ByteString.Builder.Internal.Types
                 Blaze.ByteString.Builder.Internal.Buffer
hidden-modules: Blaze.ByteString.Builder.Internal.UncheckedShifts
trusted: False
import-dirs: /usr/local/lib/ghc/blaze-builder-0.3.1.1
library-dirs: /usr/local/lib/ghc/blaze-builder-0.3.1.1
hs-libraries: HSblaze-builder-0.3.1.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
         bytestring-0.10.0.2-fdb789c5db2e1ca48eb014403eee81b4
         text-0.11.3.1-3fa3b4cb4ca4c0f49eeebe965c439ff9
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-blaze-builder-0.3.1.1/html/blaze-builder.haddock
haddock-html: /usr/local/share/doc/hs-blaze-builder-0.3.1.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-blaze-builder-0.3.3.4.tgz: lib/ghc/blaze-builder-0.3.3.4/register.sh <==
#!/bin/sh
export PATH='/usr/obj/ports/hs-blaze-builder-0.3.3.4/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: blaze-builder
version: 0.3.3.4
id: blaze-builder-0.3.3.4-876e48f76426b48714bef4b0d38f6601

license: BSD3
copyright: 2010-2014 Simon Meier
           2010 Jasper Van der Jeugt
maintainer: Simon Meier <iridcode@gmail.com>
stability: Experimental
homepage: http://github.com/meiersi/blaze-builder
package-url:
synopsis: Efficient buffered output.
description: This library provides an abstraction of buffered output of
             byte streams and several convenience functions to exploit
             it. For example, it allows to efficiently serialize
             Haskell values to lazy bytestrings with a large average
             chunk size. The large average chunk size allows to make
             good use of cache prefetching in later processing steps
             (e.g. compression) and reduces the system call overhead
             when writing the resulting lazy bytestring to a file or
             sending it over the network.
category: Data
author: Jasper Van der Jeugt, Simon Meier
pkgpath: devel/hs-blaze-builder
exposed: True
exposed-modules: Blaze.ByteString.Builder
                 Blaze.ByteString.Builder.Int Blaze.ByteString.Builder.Word
                 Blaze.ByteString.Builder.ByteString
                 Blaze.ByteString.Builder.Char.Utf8 Blaze.ByteString.Builder.Char8
                 Blaze.ByteString.Builder.Html.Utf8 Blaze.ByteString.Builder.HTTP
                 Blaze.ByteString.Builder.Internal
                 Blaze.ByteString.Builder.Internal.Write
                 Blaze.ByteString.Builder.Internal.Types
                 Blaze.ByteString.Builder.Internal.Buffer
hidden-modules: Blaze.ByteString.Builder.Internal.UncheckedShifts
trusted: False
import-dirs: /usr/local/lib/ghc/blaze-builder-0.3.3.4
library-dirs: /usr/local/lib/ghc/blaze-builder-0.3.3.4
hs-libraries: HSblaze-builder-0.3.3.4
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.7.0.2-b11c3b9ddc2bebe1a3d85499c9ea3f18
         bytestring-0.10.4.0-c38ffa96fe2b16989b0dffe49eb81a0b
         text-1.1.0.0-6c72ebcdf327be13b3762cdaa7b368bd
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-blaze-builder-0.3.3.4/html/blaze-builder.haddock
haddock-html: /usr/local/share/doc/hs-blaze-builder-0.3.3.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
